* 6-18-10
* Do file to replicate the empirical results of the "Unsuccessful Success?" paper at Comparative Political Studies.

use "Unsuccessful Success.dta", clear

**************************************************************************
* Replication Results
**************************************************************************

* Model 1: government parties
reg change opp_conf_elecdate majority gparties prime_dummy lag_pervote rgdppc_growth if xregbet==1, robust cluster(ccode)
di e(r2_a)

* Model 2: opposition parties
reg change opp_conf_elecdate opp_conf_party_elecdate majority gparties lag_pervote rgdppc_growth if xregbet==0, robust cluster(ccode)
di e(r2_a)

* Model 3: Effective parliamentary parties
reg change opp_conf_elecdate opp_conf_party_elecdate majority gparties lag_pervote rgdppc_growth eff_par eoc eoc_p if xregbet==0, robust cluster(ccode)
di e(r2_a)
test opp_conf_party_elecdate = eoc_p = 0
test opp_conf_elecdate = eoc = 0

* Model 4: Extremism
reg change opp_conf_elecdate opp_conf_party_elecdate majority gparties lag_pervote rgdppc_growth abs_rile ncm_all_abs_rile ncm_abs_rile if xregbet==0, robust cluster(ccode)
di e(r2_a)
test opp_conf_party_elecdate = ncm_abs_rile = 0
test opp_conf_elecdate = ncm_all_abs_rile = 0

**************************************************************************
* Descriptive Statistics
**************************************************************************
qui reg change opp_conf_elecdate opp_conf_party_elecdate majority gparties lag_pervote rgdppc_growth, robust cluster(ccode)
bys nation: tab ccode if e(sample)
bys nation: tab elecdate if e(sample)
bys nation: tab elecdate if e(sample) & opp_conf_elecdate>0
bys nation: tab elecdate if e(sample) & opp_conf_elecdate>1


**************************************************************************
* Figures
**************************************************************************
* Model 3
* Effective Parties
reg change opp_conf_party_elecdate eff_par eoc_p lag_pervote opp_conf_elecdate eoc rgdppc_growth majority gparties if xregbet==0, robust cluster(ccode)

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist 2(1)7 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for NCM is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle("Effective Parliamentary Parties") ytitle("Marginal Effect of No-Confidence Motion (Party)") /*
*/	note("Dashed lines represent 90% confidence intervals") legend(off)

* Model 4
* Extremism and NCM in the opposition model
reg change opp_conf_party_elecdate abs_rile ncm_abs_rile lag_pervote rgdppc_growth majority gparties opp_conf_elecdate ncm_all_abs_rile if xregbet==0, robust cluster(ccode)

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist 2(1)50 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for NCM is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle(" ""Ideological Extremism") ytitle(" ""Marginal Effect of No-Confidence Motion (Party)") /*
*/	note("Dashed lines represent 90% confidence intervals") legend(off)

capture drop vectaxis me lower_ci upper_ci

**************************************************************************
* Simple figures of the effects of NCM on vote shares
**************************************************************************
* Model 2: Opposition Parties
estsimp reg change lag_pervote rgdppc_growth majority gparties opp_conf_elecdate opp_conf_party_elecdate if xregbet==0, robust cluster(ccode) sims(1000)

capture drop ploo phio b1-b7 b8

*****
generate ploo = .
generate phio = .
generate vectaxis = .
recast float vectaxis  
local a= 0 							
local b=1							
while `a' <= 10  {                        
		setx majority 1 gparties 1 rgdppc_growth mean opp_conf_party_elecdate `a' opp_conf_elecdate 0 lag_pervote 50
	simqi, genev(ev1_opp)
	_pctile ev1_opp, p(5.0,90.0)
	display `a'
	replace ploo = r(r1) in `b'   
	replace phio = r(r2) in `b'   
	replace vectaxis = `a' in `b'    
	drop ev1_opp 
	local a = `a' + 1               
	local b=`b' + 1        
}
*****

sort vectaxis
set textsize 130
graph twoway rcap ploo phio vectaxis, msymbol(x) scheme(s1mono) bcolor(blue) msize(large) /*
*/	xtitle("No-Confidence Motions") /*
*/	ytitle("Predicted Vote Change") legend( label(1 "95% Confidence Interval | Proposing Party")) yline(0)

capture drop b1 b2 b3 b4 b5 b6 b7 b8

* Model 1: Government Parties
estsimp reg change lag_pervote rgdppc_growth majority gparties opp_conf_elecdate prime_dummy if xregbet==1, robust cluster(ccode) sims(1000)

*****
generate plog = .
generate phig = .  
local a= 0 		
local b=1		
while `a' <= 10  {  
	setx majority 1 gparties 1 rgdppc_growth mean prime_dummy 1 opp_conf_elecdate `a'  lag_pervote 50
	simqi, genev(ev1_gov)
	_pctile ev1_gov, p(5.0,90.0)
	display `a'
	replace plog = r(r1) in `b'   
	replace phig = r(r2) in `b'   
	replace vectaxis = `a' in `b'    
	drop ev1_gov 
	local a = `a' + 1  
	local b=`b' + 1    
}
*****

sort vectaxis
set textsize 130
quietly graph twoway rcap plog phig vectaxis, msymbol(x) scheme(s1mono) bcolor(blue) msize(large) /*
*/	xtitle("No-Confidence Motions") /*
*/	ytitle("Predicted Vote Change") legend( label(1 "95% Confidence Interval | Executive Party")) yline(0)

graph twoway rcap plog phig vectaxis, scheme(s1mono) bcolor(blue) msize(large) || /*
*/	rcapsym ploo phio vectaxis, msymbol(x) bcolor(black) msize(large) /*
*/	xtitle("No-Confidence Motions") /*
*/	ytitle("Predicted Vote Change") legend( label(1 "95% Confidence Interval | Executive Party") /*
*/	label(2 "95% Confidence Interval | Proposing Party")col(1)) yline(0)

capture drop b1 b2 b3 b4 b5 b6 b7 b8 ploo phio vectaxis plog phig
