***************************************************************************
*** This do file replicates the results and recreates figures for Whitten and Williams "Buttery Guns and Welfare Hawks", AJPS 2011.
***
*** NOTE: Make sure to set up the working directory and place all of the programs in that folder.
***
***************************************************************************


**********************************************************
* Set up a working directory and open the "Whitten and Williams 2011.dta" file
**********************************************************
* Working directory
*cd ""

* Open the data set
use "Whitten and Williams 2011.dta", clear


****************************************************************************
* Additive and Interactive Models of Defense Spending (Tables 3 & 4)
****************************************************************************

* Additive: One-Dimensional Model
xtpcse milex_gdp lag_milex_gdp GOV_rl gthreat GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

* Additive: Two-Dimensional Model
xtpcse milex_gdp lag_milex_gdp GOV_welfare GOV_hawk1 gthreat GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

* Interactive: One-Dimensional Model
xtpcse milex_gdp lag_milex_gdp GOV_rl gthreat gthreat_GOV_rl GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

* Interactive: Two-Dimensional Model
xtpcse milex_gdp lag_milex_gdp GOV_welfare GOV_hawk1 gthreat gthreat_GOV_welfare gthreat_GOV_hawk1 GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 



*******************************************************************************************************************
*******************************************************************************************************************
* Figure 1: Distribution of Government Positions across Two Dimensions
*******************************************************************************************************************
*******************************************************************************************************************
quietly xtpcse milex_gdp lag_milex_gdp GOV_welfare GOV_hawk1 gthreat gthreat_GOV_welfare gthreat_GOV_hawk1 GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

preserve
	keep if e(sample)
	
	pwcorr GOV_hawk1 GOV_welfare GOV_rl, sig obs
	summarize GOV_hawk1 GOV_welfare GOV_rl, detail
	quietly summarize GOV_hawk1, detail
	local D = r(p5)
	local H = r(p95)
	local i_med = r(p50)

	quietly summarize GOV_welfare, detail
	local A = r(p5)
	local G = r(p95)
	local w_med = r(p50)

	twoway scatter GOV_hawk1 GOV_welfare, /*
	*/ yline(`i_med') xline(`w_med') msize(*.6) /*
	*/ xtitle("Austere								                        Generous" "Welfare Position") /*
	*/ ytitle("International Position" "			Dove					                                    Hawk                               ")  /*
	*/ text(`D' `A' "AD") /*
	*/ text(`D' `G' "GD") /*
	*/ text(`H' `A' "AH") /*
	*/ text(`H' `G' "GH") /*
	*/ scheme(s1mono) note("Note: Lines depict the median value for each variable.  Abbreviations depict the four archetypes" "used in the simulations: Austerity-Hawk, Generous-Hawk, Austerity-Dove, and Generous-Dove.")
restore


************************************************************************************************************************
************************************************************************************************************************
*** Figure 2: Estimated contingent effects of government right-left position and conflict involvement on defense spending.
************************************************************************************************************************
************************************************************************************************************************

*** Left panel
qui xtpcse milex_gdp GOV_rl gthreat gthreat_GOV_rl lag_milex_gdp GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist 0(1)14 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for Government Partisanship is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x* upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle("  ""No Conflicts							Conflicts" "Conflict Involvement") ytitle("Marginal Effect of Government Left-Right Position") /*
*/	legend(off) name(me_part_one, replace) nodraw

*** Right panel
qui xtpcse milex_gdp gthreat GOV_rl gthreat_GOV_rl lag_milex_gdp GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist -31(1)30 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for International Threat is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x* upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle("  ""Left									Right" "Government Left-Right Position") ytitle("Marginal Effect of Conflict Involvement") /*
*/	legend(off)  name(me_threat_one, replace) nodraw

graph combine me_part_one me_threat_one, note("Dashed lines represent 90% confidence intervals") 


************************************************************************************************************************
************************************************************************************************************************
*** Figure 3: Estimated contingent effects of government welfare position and conflict involvement on defense spending.
************************************************************************************************************************
************************************************************************************************************************

*** Left panel
qui xtpcse milex_gdp GOV_welfare gthreat gthreat_GOV_welfare GOV_hawk1 gthreat_GOV_hawk1 lag_milex_gdp GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist 0(1)13 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for Government Welfare is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x* upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle("  ""No Conflicts								Conflicts" "Conflict Involvement") ytitle("Marginal Effect of Government Welfare Position") /*
*/	legend(off) name(me_welfare_two, replace) nodraw

*** Right panel
qui xtpcse milex_gdp gthreat GOV_welfare gthreat_GOV_welfare GOV_hawk1 gthreat_GOV_hawk1 lag_milex_gdp GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist 3(1)22 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for International Threat is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x* upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle("  ""Austere								Generous" "Government Welfare Position") ytitle("Marginal Effect of Conflict Involvement") /*
*/	legend(off)  name(me_threat_welfare_two, replace) nodraw

graph combine me_welfare_two me_threat_welfare_two, note("Dashed lines represent 90% confidence intervals")

************************************************************************************************************************
************************************************************************************************************************
*** Figure 4: Estimated contingent effects of government international position and conflict involvement on defense spending.
************************************************************************************************************************
************************************************************************************************************************

*** Left panel
xtpcse milex_gdp GOV_hawk1 gthreat gthreat_GOV_hawk1 GOV_welfare gthreat_GOV_welfare lag_milex_gdp GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist 0(1)13 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for Government Hawk is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x* upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle("  ""No Conflicts								Conflicts" "Conflict Involvement") ytitle("Marginal Effect of Government International Position") /*
*/	legend(off) name(me_hawk_two, replace) nodraw

*** Right panel
xtpcse milex_gdp gthreat GOV_hawk1 gthreat_GOV_hawk1 GOV_welfare gthreat_GOV_welfare lag_milex_gdp GOV_min GOV_npty election_yr lag_real_GDP_gr cinclag lag_alliance lag_cinc_ratio lag_us_change_milex_gdp, c(psar1) 

matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1] 
scalar varb3=V[3,3]
scalar covb1b3=V[1,3] 

capture drop vectaxis me lower_ci upper_ci
gen vectaxis = .
gen me = .
gen lower_ci = .
gen upper_ci = .
local b = 1

foreach i of numlist -4(1)4 {
	local n = 1
	qui gen conb = b1 + (b3*(`i'))
	local conse = sqrt(varb1+varb3*((`i')^2)+2*covb1b3*(`i'))
	qui gen x=1.65*`conse'
 	qui gen upper=conb+x
	qui gen lower=conb-x
	qui sum conb
		local me = `r(mean)'
		replace me = `me' in `b'
	qui sum lower 
		local lower_ci = `r(mean)'
		replace lower_ci = `lower_ci' in `b'
	qui sum upper
		local upper_ci = `r(mean)'
		replace upper_ci = `upper_ci' in `b'
	di
	di
	di "The marginal effect for International Threat is " `me'
	di "The confidence interval is " `lower_ci' 	"	and		"	`upper_ci'
	di "The modifying variable is = 	" `i'
	di 
	di
	capture drop conb* x* upper lower
	replace vectaxis = `i' in `b'
	local b = `b' + 1
	local n = `n' + 1
}

twoway (line me vectaxis, clpattern(solid) sort) (line lower_ci vectaxis, clpattern(dash) sort) (line upper_ci vectaxis, clpattern(dash) sort), /*
*/	yline(0) xtitle("  ""Dove								Hawk" "Government International Position") ytitle("Marginal Effect of Conflict Involvement") /*
*/	legend(off)  name(me_threat_hawk_two, replace) nodraw

graph combine me_hawk_two me_threat_hawk_two, note("Dashed lines represent 90% confidence intervals") 


*******************************************************************************************************************
*******************************************************************************************************************
* Figure 5: Predicted defense spending by four government types over 40 years of peace
*******************************************************************************************************************
*******************************************************************************************************************
sort ccode year

dynsim_pcse if ccode>2 & ccode!=255 & ccode!=395 & ccode!=740, dv(milex_gdp) ldv(lag_milex_gdp) ldv_val(2.348012) pv(ccode)  time(year) /*
*/	scen1(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr 0 cinclag mean gthreat 0  lag_alliance 0 gthreat_GOV_welfare 0 gthreat_GOV_hawk1 0 GOV_min 0 GOV_npty 1 election_yr 0 GOV_welfare 2.89  GOV_hawk1 3.75 )  /*
*/	scen2(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr 0 cinclag mean gthreat 0  lag_alliance 0 gthreat_GOV_welfare 0 gthreat_GOV_hawk1 0 GOV_min 0 GOV_npty 1 election_yr 0 GOV_welfare 22.23 GOV_hawk1 3.75 )  /*
*/	scen3(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr 0 cinclag mean gthreat 0  lag_alliance 0 gthreat_GOV_welfare 0 gthreat_GOV_hawk1 0 GOV_min 0 GOV_npty 1 election_yr 0 GOV_welfare 2.89  GOV_hawk1 -3.56 )  /*
*/	scen4(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr 0 cinclag mean gthreat 0  lag_alliance 0 gthreat_GOV_welfare 0 gthreat_GOV_hawk1 0 GOV_min 0 GOV_npty 1 election_yr 0 GOV_welfare 22.23 GOV_hawk1 -3.56 )  /*
*/	 command(xtpcse) estoptions(c(psar1)) sims(10000) n(40) /*
*/	scheme(s1mono) ytitle("Military Expenditures as % of GDP") /*
*/ legend(label(1 "Austerity-Hawk") label(2 "Generous-Hawk") label(3 "Austerity-Dove") label(4 "Generous-Dove")) /*
*/ note("Note: bars depict 95% confidence intervals") /*
*/ xtitle("Year + t")

*******************************************************************************************************************
*******************************************************************************************************************
* Figure 6: predicted defense spending by four government types over 40 years of Swedish conflict involvement
*******************************************************************************************************************
*******************************************************************************************************************
dynsim_pcse if ccode>2 & ccode!=255 & ccode!=395 & ccode!=740, dv(milex_gdp) ldv(lag_milex_gdp) ldv_val(2.348012) pv(ccode) pv_start(1950) time(year) /*
*/	scen1(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 2.89 gthreat_GOV_hawk1 3.75 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 2.89 GOV_hawk1 3.75)  /*
*/	scen2(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 22.23 gthreat_GOV_hawk1 3.75 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 22.23 GOV_hawk1 3.75)  /*
*/	scen3(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 2.89 gthreat_GOV_hawk1 -3.56 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 2.89 GOV_hawk1 -3.56)  /*
*/	scen4(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 22.23 gthreat_GOV_hawk1 -3.56 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 22.23 GOV_hawk1 -3.56)  /*
*/	command(xtpcse) estoptions(c(psar1))  sims(10000) n(40)  shock(gthreat) /*
*/	shock_data("C:\Users\\$D\Documents\Research\Methods\Software\Dynamic Simulations\Shock\Sweden shock.dta") /*
*/	inter(gthreat_GOV_welfare gthreat_GOV_hawk1) /*
*/	scheme(s1mono) ytitle("Military Expenditures as % of GDP")  yscale(range(0.5 4) axis(1)) yscale(range(0 150) axis(2)) ylabel(0 10, axis(2))/*
*/ legend(label(1 "Austerity-Hawk") label(2 "Generous-Hawk") label(3 "Austerity-Dove") label(4 "Generous-Dove") label(5 "Conflict Involvement")) /*
*/ note("Note: bars depict 95% confidence intervals") /*
*/ xtitle("Year + t")  ytitle("	Conflict Involvement                                          ", axis(2))

*******************************************************************************************************************
*******************************************************************************************************************
* Figure 7: predicted defense spending by four government types over 40 years of French conflict involvement
*******************************************************************************************************************
*******************************************************************************************************************
dynsim_pcse if ccode>2 & ccode!=255 & ccode!=395 & ccode!=740, dv(milex_gdp) ldv(lag_milex_gdp) ldv_val(2.348012) pv(ccode) pv_start(1950) time(year) /*
*/	scen1(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 2.89 gthreat_GOV_hawk1 3.75 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 2.89 GOV_hawk1 3.75)  /*
*/	scen2(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 22.23 gthreat_GOV_hawk1 3.75 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 22.23 GOV_hawk1 3.75)  /*
*/	scen3(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 2.89 gthreat_GOV_hawk1 -3.56 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 2.89 GOV_hawk1 -3.56)  /*
*/	scen4(lag_us_change_milex_gdp mean lag_cinc_ratio mean lag_real_GDP_gr mean cinclag mean lag_alliance mean gthreat_GOV_welfare 22.23 gthreat_GOV_hawk1 -3.56 GOV_min mean GOV_npty mean election_yr mean GOV_welfare 22.23 GOV_hawk1 -3.56)  /*
*/	command(xtpcse) estoptions(c(psar1)) sims(10000) n(40) shock(gthreat) /*
*/	shock_data("C:\Users\\$D\Documents\Research\Methods\Software\Dynamic Simulations\Shock\France shock.dta") /*
*/	inter(gthreat_GOV_welfare gthreat_GOV_hawk1) /*
*/	scheme(s1mono) ytitle("Military Expenditures as % of GDP") yscale(range(0.5 4) axis(1)) yscale(range(0 150) axis(2))  ylabel(0(20)40, axis(2))/*
*/ legend(label(1 "Austerity-Hawk") label(2 "Generous-Hawk") label(3 "Austerity-Dove") label(4 "Generous-Dove") label(5 "Conflict Involvement")) /*
*/ note("Note: bars depict 95% confidence intervals") /*
*/ xtitle("Year + t") ytitle("	International Conflict                                          ", axis(2)) 

*******************************************************************************************************************
*******************************************************************************************************************
* Tables 2 and 3: Long-Term Effects
*******************************************************************************************************************
*******************************************************************************************************************

*** Additive One-Dimensional
capture drop b1-b12 b13
estsimp_pcse xtpcse milex_gdp lag_milex_gdp lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio GOV_rl,  c(psar1)

local conf = .05								/* statistical significance level*/
local percentage = (1-`conf')*100
local low_conf = (`conf'/2)*1000
local upper_conf = 1000-((`conf'/2)*1000)
local i = 2									/* iteration starts at b2 (b1 is the laggedDV)*/

foreach x of varlist lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio GOV_rl {
	quietly gen LTE_`x' = b`i'/(1-b1)
	sort LTE_`x'
	quietly sum LTE_`x', det
	local mn_`x' = round(r(mean),.001)
	_pctile LTE_`x', p(2.5,97.5)
	local low_`x' = round(r(r1),.001)
	local upper_`x' = round(r(r2),.001)

	local i = `i' + 1

	di as result _dup(79) "-"
	di as result "Variable" _col(25) "Long-Term Effect" _col(55)"`percentage'% Confidence Interval"
	di as result _col(50)"Lower" _col(72)"Upper"
	di as result _dup(79) "-"
	di as result "`x'" _col(25) %9.2f "`mn_`x''" _col(50)"`low_`x''" _col(72)"`upper_`x''"
	di as result "{hline 79}"
}
capture drop LTE_*


*** Additive Two-Dimensional
capture drop b1-b12 b13
estsimp_pcse xtpcse milex_gdp lag_milex_gdp lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio GOV_welfare  GOV_hawk1 if ccode>2 & ccode!=255 & ccode!=395 & ccode!=740, c(psar1)

local conf = .05								/* statistical significance level*/
local percentage = (1-`conf')*100
local low_conf = (`conf'/2)*1000
local upper_conf = 1000-((`conf'/2)*1000)
local i = 2									/* iteration starts at b2 (b1 is the laggedDV)*/

foreach x of varlist lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio GOV_welfare  GOV_hawk1 {
	quietly gen LTE_`x' = b`i'/(1-b1)
	sort LTE_`x'
	quietly sum LTE_`x', det
	local mn_`x' = round(r(mean),.001)
	_pctile LTE_`x', p(2.5,97.5)
	local low_`x' = round(r(r1),.001)
	local upper_`x' = round(r(r2),.001)

	local i = `i' + 1
	
	di as result _dup(79) "-"
	di as result "Variable" _col(25) "Long-Term Effect" _col(55)"`percentage'% Confidence Interval"
	di as result _col(50)"Lower" _col(72)"Upper"
	di as result _dup(79) "-"
	di as result "`x'" _col(25) %9.2f "`mn_`x''" _col(50)"`low_`x''" _col(72)"`upper_`x''"
	di as result "{hline 79}"
}
capture drop LTE_*

*** Interactive One-Dimensional Model
capture drop b1-b13 b14
estsimp_pcse xtpcse milex_gdp lag_milex_gdp lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio gthreat_GOV_rl GOV_rl if ccode>2 & ccode!=255 & ccode!=395 & ccode!=740,  c(psar1)

local conf = .05								/* statistical significance level*/
local percentage = (1-`conf')*100
local low_conf = (`conf'/2)*1000
local upper_conf = 1000-((`conf'/2)*1000)
local i = 2									/* iteration starts at b2 (b1 is the laggedDV)*/

foreach x of varlist lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio gthreat_GOV_rl GOV_rl {
	quietly gen LTE_`x' = b`i'/(1-b1)
	sort LTE_`x'
	quietly sum LTE_`x', det
	local mn_`x' = round(r(mean),.001)
	_pctile LTE_`x', p(2.5,97.5)
	local low_`x' = round(r(r1),.001)
	local upper_`x' = round(r(r2),.001)

	local i = `i' + 1
	
	di as result _dup(79) "-"
	di as result "Variable" _col(25) "Long-Term Effect" _col(55)"`percentage'% Confidence Interval"
	di as result _col(50)"Lower" _col(72)"Upper"
	di as result _dup(79) "-"
	di as result "`x'" _col(25) %9.2f "`mn_`x''" _col(50)"`low_`x''" _col(72)"`upper_`x''"
	di as result "{hline 79}"
}
capture drop LTE_*

*** Interactive Two-Dimensional Model
capture drop b1-b13 b14

estsimp_pcse xtpcse milex_gdp lag_milex_gdp lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio GOV_welfare gthreat_GOV_welfare GOV_hawk1 gthreat_GOV_hawk1 if ccode>2 & ccode!=255 & ccode!=395 & ccode!=740, c(psar1)

local conf = .05								/* statistical significance level*/
local percentage = (1-`conf')*100
local low_conf = (`conf'/2)*1000
local upper_conf = 1000-((`conf'/2)*1000)
local i = 2									/* iteration starts at b2 (b1 is the laggedDV)*/

foreach x of varlist lag_real_GDP_gr cinclag gthreat lag_alliance GOV_min GOV_npty election_yr lag_us_change_milex_gdp lag_cinc_ratio GOV_welfare gthreat_GOV_welfare GOV_hawk1 gthreat_GOV_hawk1 {
	quietly gen LTE_`x' = b`i'/(1-b1)
	sort LTE_`x'
	quietly sum LTE_`x', det
	local mn_`x' = round(r(mean),.001)
	_pctile LTE_`x', p(2.5,97.5)
	local low_`x' = round(r(r1),.001)
	local upper_`x' = round(r(r2),.001)

	local i = `i' + 1

	di as result _dup(79) "-"
	di as result "Variable" _col(25) "Long-Term Effect" _col(55)"`percentage'% Confidence Interval"
	di as result _col(50)"Lower" _col(72)"Upper"
	di as result _dup(79) "-"
	di as result "`x'" _col(25) %9.2f "`mn_`x''" _col(50)"`low_`x''" _col(72)"`upper_`x''"
	di as result "{hline 79}"
}
capture drop LTE_*
capture drop b1-b15 b16

